pub enum ConfigStrategy {
App,
Native,
}Expand description
Determine what strategy confy should use
these are based off of the etcetera crate’s strategies.
To change use change_config_strategy function before calling any load or save functions.
Variants
App
The App Strategy is the default strategy
this is the traditional XDG strategy and will place the config file in the XDG directories.
See Etcetera App Strategy for more information.
Native
The Native Strategy is mainly used for GUI applications and places the config directory based on the
host systems determination. See Etcetera Native Strategy for more information.